(use-modules (aiscm core) (aiscm magick))
(write-image (arr (32 255 96 255) (255 160 255 224)) "pattern.png")
